@@ -1,8 +1,8 @@
 import arcade
 ### default win size
 
-WIN_WIDTH = 500
-WIN_HEIGHT = 800
+WIN_WIDTH = 400
+WIN_HEIGHT = 600
 
 ###
 
@@ -25,7 +25,7 @@ DT_SPLIT = DT_UPDATE / DT_SPLIT_NUM
 GRAVITY = [0, -800]
 DENSITY = 0.01
 FRICTION = 0.5
-ELASTICITY = 0.95
+ELASTICITY = 0.3
 
 
 
@@ -79,4 +79,4 @@ is_engine_created = False
 
 # stage is a physics engine
 stage = None
-物理舞台 = None
\ No newline at end of file
+舞台 = None
\ No newline at end of file
